            #GIT_CMT=c3cc4698d0fc09582dc1e7f3b359827b55175def
# -*- rpm-spec -*-


%global with_guestfs               0
%global stable_defaults            0
%global askpass_package            "openssh-askpass"
%global qemu_user                  "qemu"
%global libvirt_packages           "libvirt-daemon-kvm,libvirt-daemon-config-network"
%global kvm_packages               ""
%global preferred_distros          "fedora,rhel"
%global default_hvs                "qemu,xen,lxc"

%if 0%{?rhel}
%global preferred_distros          "rhel,fedora"
%global stable_defaults            1
%endif

%{!?buildid: %{expand: %%define buildid 1}}
# End local config

Name: virt-manager
Version: 1.5.0
Release:    21.el7
%global verrel %{version}-%{release}

Summary: Desktop tool for managing virtual machines via libvirt
Group: Applications/Emulators
License: GPLv2+
BuildArch: noarch
URL: http://virt-manager.org/
Source0: virt-manager-1.5.0.tar.bz2


Requires: virt-manager-common = %{verrel}
Requires: pygobject3
Requires: gtk3
Requires: libvirt-glib >= 0.0.9
Requires: dconf
Requires: dbus-x11

# The vte291 package is actually the latest vte with API version 2.91, while
# the vte3 package is effectively a compat package with API version 2.90.
# virt-manager works fine with either, so pull the latest bits so there's
# no ambiguity.
Requires: vte291

# For console widget
Requires: gtk-vnc2
Requires: spice-gtk3

%if 0%{?rhel} == 7
Requires: gnome-icon-theme
%endif


BuildRequires: intltool
BuildRequires: /usr/bin/pod2man
# For python, and python2 rpm macros
BuildRequires: python2-devel


%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and LXC. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the backend
management API.


%package common
Summary: Common files used by the different Virtual Machine Manager interfaces
Group: Applications/Emulators

# This version not strictly required: virt-manager should work with older,
# however varying amounts of functionality will not be enabled.
Requires: libvirt-python >= 0.7.0
Requires: libxml2-python
Requires: python-requests
Requires: python-ipaddr
Requires: libosinfo >= 0.2.10
# Required for gobject-introspection infrastructure
Requires: pygobject3-base
# Required for pulling files from iso media with isoinfo
Requires: genisoimage

%description common
Common files used by the different virt-manager interfaces, as well as
virt-install related tools.


%package -n virt-install
Summary: Utilities for installing virtual machines

Requires: virt-manager-common = %{verrel}
# For 'virsh console'
Requires: libvirt-client

Provides: virt-install
Provides: virt-clone
Provides: virt-convert
Provides: virt-xml
Obsoletes: python-virtinst

%description -n virt-install
Package includes several command line utilities, including virt-install
(build and install new VMs) and virt-clone (clone an existing virtual
machine).


%prep
%setup -q


%build
%if %{qemu_user}
%global _qemu_user --qemu-user=%{qemu_user}
%endif

%if %{kvm_packages}
%global _kvm_packages --kvm-package-names=%{kvm_packages}
%endif

%if %{preferred_distros}
%global _preferred_distros --preferred-distros=%{preferred_distros}
%endif

%if %{libvirt_packages}
%global _libvirt_packages --libvirt-package-names=%{libvirt_packages}
%endif

%if %{askpass_package}
%global _askpass_package --askpass-package-names=%{askpass_package}
%endif

%if %{stable_defaults}
%global _stable_defaults --stable-defaults
%endif

%if %{default_hvs}
%global _default_hvs --default-hvs %{default_hvs}
%endif

python setup.py configure \
    %{?_qemu_user} \
    %{?_kvm_packages} \
    %{?_libvirt_packages} \
    %{?_askpass_package} \
    %{?_preferred_distros} \
    %{?_stable_defaults} \
    %{?_default_hvs}


%install
python setup.py \
    --no-update-icon-cache --no-compile-schemas \
    install -O1 --root=%{buildroot}
%find_lang %{name}

# Replace '#!/usr/bin/env python2' with '#!/usr/bin/python2'
# The format is ideal for upstream, but not a distro. See:
# https://fedoraproject.org/wiki/Features/SystemPythonExecutablesUseSystemPython
for f in $(find %{buildroot} -type f -executable -print); do
    sed -i "1 s|^#!/usr/bin/env python2|#!%{__python2}|" $f || :
done

# The conversion script was only added to virt-manager after several
# Fedora cycles of using gsettings. Installing it now could convert old data
# and wipe out recent settings.
rm %{buildroot}%{_datadir}/GConf/gsettings/org.virt-manager.virt-manager.convert


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi
/usr/bin/update-desktop-database &> /dev/null || :


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :


%files
%doc README.md COPYING NEWS.md
%{_bindir}/%{name}

%{_mandir}/man1/%{name}.1*

%{_datadir}/%{name}/ui/*.ui
%{_datadir}/%{name}/virt-manager
%{_datadir}/%{name}/virtManager

%{_datadir}/%{name}/icons
%{_datadir}/icons/hicolor/*/apps/*

%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.virt-manager.virt-manager.gschema.xml


%files common -f %{name}.lang
%dir %{_datadir}/%{name}

%{_datadir}/%{name}/virtcli
%{_datadir}/%{name}/virtconv
%{_datadir}/%{name}/virtinst


%files -n virt-install
%{_mandir}/man1/virt-install.1*
%{_mandir}/man1/virt-clone.1*
%{_mandir}/man1/virt-convert.1*
%{_mandir}/man1/virt-xml.1*

%{_datadir}/%{name}/virt-install
%{_datadir}/%{name}/virt-clone
%{_datadir}/%{name}/virt-convert
%{_datadir}/%{name}/virt-xml

%{_bindir}/virt-install
%{_bindir}/virt-clone
%{_bindir}/virt-convert
%{_bindir}/virt-xml
%changelog
* Sat Oct 2 2021 Karl Heubaum <karl.heubaum@oracle.com> - 1.5.0-21.el7
- virtinst: Add support for ioapic (Karl Heubaum)

* Fri Sep 11 2020 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-20.el7
- virtinst: stop configuring target.node for the expander bus on Exadata (Menno
  Lageman)  [Orabug: 31793077]

* Thu Jun 25 2020 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-19.el7
- virtinst: stop configuring the IOMMU through qemu:commandline (Menno Lageman)  
- virtinst: add support for configuring the IOMMU (Menno Lageman)  
- virtinst: don't set CPU features with qemu:commandline (Menno Lageman)  [Orabug: 31374547] 
- virtinst: add support for host-phys-bits KVM feature (Menno Lageman)  [Orabug: 31374547] 
- virt-install: Add two more pcie-root-port slots to the Exadata machine template (Wim ten Have)  [Orabug: 31080601]

* Mon Feb 03 2020 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-18.el7
- virtinst: add support for <vnuma> (Menno Lageman)  [Orabug: 30589830]

* Wed Oct 16 2019 Wim ten Have <wim.ten.have@oracle.com> - 1.5.0-17.el7
- virtinst: Always enable vNUMA on Exadata guests (Menno Lageman)  [Orabug:
  30410874]

* Tue Sep 10 2019 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-16.el7
- virtinst: Exadata: don't add target node on non-NUMA systems (Menno Lageman)  [Orabug: 30284679] 
- If user renames guest in VM details page before installation starts there is no need to rename NVRAM file as well. (Pavel Hrdina)  [Orabug: 29954660] 
- virtinst: require at least 2 threads per NUMA node for Exadata (Menno Lageman)  [Orabug: 30081399]

* Mon Jun 24 2019 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-15.el7
- tests: fix missing '<rng model="virtio" .../>' (Menno Lageman)  [Orabug: 29947518] 
- tests: fix missing '<model type="e1000"/>' (Menno Lageman)  [Orabug: 29947518] 
- virtinst: set virtio-scsi queues to number of vcpus (Menno Lageman)  [Orabug: 29947518] 
- virtinst: allow setting the number of queues for controllers (Menno Lageman)  [Orabug: 29947518]

* Mon Jun 17 2019 Wim ten Have <wim.ten.have@oracle.com> - 1.5.0-14.el7
- virtinst: add qemu extended args for large guests unconditionally (Wim ten
  Have)  [Orabug: 29919946]

* Wed Jun 12 2019 Wim ten Have <wim.ten.have@oracle.com> - 1.5.0-13.el7
- virtinst: Invariant TSC feature on large guests can't be migrated. (Wim ten
  Have)  [Orabug: 29797342]

* Thu Jun 06 2019 Wim ten Have <wim.ten.have@oracle.com> - 1.5.0-12.el7
- Revert "virtinst: disable memballoon device for Exadata" (Wim ten Have)
  [Orabug: 29878086]

* Tue May 14 2019 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-11.el7
- virtinst: support >= 1 TB guests on Exadata (Menno Lageman)  [Orabug: 29683989] 
- virtinst: switch to 'virtio-scsi' for Exadata (Menno Lageman)  [Orabug: 29660043]

* Wed Apr 17 2019 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-10.el7
- virt-manager: add 'Oracle Linux' group to OS options view (Menno Lageman)
  [Orabug: 29659677]

* Tue Mar 26 2019 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-9.el7
- virtinst: allow --cpu together with --vnuma (Menno Lageman)

* Mon Mar 04 2019 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-8.el7
- virtinst: lookup NUMA node for Infiniband devices on Exadata (Menno Lageman)

* Thu Jan 31 2019 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-7.el7
- virtinst: disable memballoon device for Exadata (Menno Lageman)

* Fri Dec 14 2018 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-6.el7
- virtinst: test for NUMA should not use /proc/sys/kernel/numa_balancing (Menno Lageman)  [Orabug: 29054217] 
- virtinst: --vnuma option no longer creates a vNUMA config (Menno Lageman)  [Orabug: 29044985]

* Thu Dec 06 2018 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-5.el7
- virtinst: enable hugepages for Exadata guests (Menno Lageman)

* Mon Dec 03 2018 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-4.el7
- virtinst: configure devices for Exadata guests (Menno Lageman)  
- virt-manager: change 'new-vm' defaults to more sane values (Menno Lageman)  [Orabug: 28892829]

* Fri Sep 21 2018 Menno Lageman <menno.lageman@oracle.com> - 1.5.0-3.el7
- BUILDINFO: commit=f56741560d32633d2421b7ccd227e2f718e5bfe3
- virtinst: add KVM features kvm_cpu_pm, kv_mem_lock, and kvm_hint_dedicated (Menno Lageman)  
- virtinst: add --exadata option (Menno Lageman)  
- virtinst: add --vnuma autopartition option (Menno Lageman)

* Sun Mar 04 2018 Wim ten Have <wim.ten.have@oracle.com> - 1.5.0-2.el7
- BUILDINFO: commit=3178e25b189b86defb1cb34d5ce21bb464131bd7
- virt-manager: buildrpm changes for OL7u4 build v1.5.0

